const PDFView = ({data}) => {
    useEffect(() => {
        if(data.slides){
            const url = "uploaded/" + data.slides;
            console.log(url);
            // Loaded via <script> tag, create shortcut to access PDF.js exports.
            var { pdfjsLib } = globalThis;
        
            // // The workerSrc property shall be specified.
            pdfjsLib.GlobalWorkerOptions.workerSrc = "https://cdn.jsdelivr.net/npm/pdfjs-dist@2.7.570/build/pdf.worker.min.js";
        
            var pdfDoc = null,
                pageNum = 1,
                pageRendering = false,
                pageNumPending = null,
                scale = 0.7,
                canvas = document.getElementById('the-canvas'),
                ctx = canvas.getContext('2d');
        
            /**
             * Get page info from document, resize canvas accordingly, and render page.
             * @param num Page number.
             */
            function renderPage(num) {
            pageRendering = true;
            // Using promise to fetch the page
            pdfDoc.getPage(num).then(function(page) {
                var viewport = page.getViewport({scale: scale});
                canvas.height = viewport.height;
                canvas.width = viewport.width;
        
                // Render PDF page into canvas context
                var renderContext = {
                canvasContext: ctx,
                viewport: viewport
                };
                var renderTask = page.render(renderContext);
        
                // Wait for rendering to finish
                renderTask.promise.then(function() {
                pageRendering = false;
                if (pageNumPending !== null) {
                    // New page rendering is pending
                    renderPage(pageNumPending);
                    pageNumPending = null;
                }
                });
            });
        
            // Update page counters
            document.getElementById('progress').setAttribute("value", num);
            document.getElementById('page_num').textContent = num;
            }
        
            /**
             * If another page rendering in progress, waits until the rendering is
             * finised. Otherwise, executes rendering immediately.
             */
            function queueRenderPage(num) {
            if (pageRendering) {
                pageNumPending = num;
            } else {
                renderPage(num);
            }
            }
        
            /**
             * Displays previous page.
             */
            function onPrevPage() {
            if (pageNum <= 1) {
                return;
            }
            pageNum--;
            queueRenderPage(pageNum);
            }
            document.getElementById('prev').addEventListener('click', onPrevPage);
        
            /**
             * Displays next page.
             */
            function onNextPage() {
            if (pageNum >= pdfDoc.numPages) {
                return;
            }
            pageNum++;
            queueRenderPage(pageNum);
            }
            document.getElementById('next').addEventListener('click', onNextPage);
        
            /**
             * Asynchronously downloads PDF.
             */
            pdfjsLib.getDocument(url).promise.then(function(pdfDoc_) {
            pdfDoc = pdfDoc_;
            document.getElementById('progress').setAttribute("max", pdfDoc.numPages);
            document.getElementById('page_count').textContent = pdfDoc.numPages;
        
            // Initial/first page rendering
            renderPage(pageNum);
            });
        }
        
    }, [data]);

    return(
        <div className="columns is-mobile is-centered">
            <div className="column" style={{textAlign: "center"}}>
                <canvas id="the-canvas"></canvas>
                <progress id="progress" className="progress is-link" value="15" max="100" style={{marginTop: "30px", height: "10px", width: "100%", display: "inline-block"}}></progress>
                <div style={{display: "flex", justifyContent: "center"}}>
                    <button id="prev" className="button" style={{marginRight: "20px"}}>{"<"}</button>
                    <span style={{marginTop: "8px"}}>Page: <span id="page_num"></span> / <span id="page_count"></span></span>
                    <button id="next"  className="button"  style={{marginLeft: "20px"}}>{">"}</button>
                </div>
            </div>
        </div>
    );
}